@@ -3,6 +3,7 @@ import copy
 import io
 import json
 import pathlib
+import warnings
 
 import h5py
 import numpy as np
@@ -71,9 +72,15 @@ class AFMData(abc.ABC):
             length = self._metadata["point count"]
         return length
 
-    @abc.abstractmethod
+    def __str__(self):
+        strre = "{} '{}'[{}]".format(
+            self.__class__.__name__, self.path, self.enum)
+        return strre
+
     def __repr__(self):
-        """Meaningful repr string"""
+        repre = "<{} '{}'[{}] at {}>".format(
+            self.__class__.__name__, self.path, self.enum, hex(id(self)))
+        return repre
 
     @property
     def columns(self):
@@ -97,7 +104,7 @@ class AFMData(abc.ABC):
 
     @property
     @abc.abstractmethod
-    def mode(self):
+    def modality(self):
         """Imaging modality (e.g. force-distance)"""
 
     @property
@@ -197,8 +204,13 @@ class AFMData(abc.ABC):
                     items.append("{:.8g}".format(data[cc][ii]))
             fd.write("\t".join(items) + "\r\n")
 
-    def export(self, out, metadata=True, fmt="tab"):
-        """Export all columns to a file
+    def export(self, *args, **kwargs):
+        warnings.warn("Pleas use `export_data` for data export!",
+                      DeprecationWarning)
+        return self.export_data(*args, **kwargs)
+
+    def export_data(self, out, metadata=True, fmt="tab"):
+        """Export all data columns to a file
 
         Parameters
         ----------
