@@ -8,7 +8,7 @@ import pytest
 import afmformats
 
 
-datadir = pathlib.Path(__file__).resolve().parent / "data"
+data_path = pathlib.Path(__file__).resolve().parent / "data"
 
 
 def test_bad_recipe_loader_missing():
@@ -69,12 +69,13 @@ def test_bad_recipe_suffix_invalid():
 
 
 @pytest.mark.parametrize("name, is_valid",
-    [("spot3-0192.jpk-force", True),  # noqa: E128
-     ("map2x2_extracted.jpk-force-map", True),
-     ("calibration_force-save-2015.02.04-11.25.21.294.jpk-force", False),
+    [("fmt-jpk-fd_spot3-0192.jpk-force", True),  # noqa: E128
+     ("fmt-jpk-fd_map2x2_extracted.jpk-force-map", True),
+     ("fmt-jpk-cl_calibration_force-save-2015.02.04-11.25.21.294.jpk-force",
+      False),
      ])
 def test_find_data(name, is_valid):
-    file = datadir / name
+    file = data_path / name
     file_list = afmformats.find_data(file)
     assert bool(len(file_list)) == is_valid
 
@@ -85,17 +86,19 @@ def test_find_data_recursively():
     td2.mkdir(exist_ok=True, parents=True)
     td3 = td / "test" / "recur2"
     td3.mkdir(exist_ok=True, parents=True)
-    shutil.copy2(datadir / "spot3-0192.jpk-force", td2)
+    shutil.copy2(data_path / "fmt-jpk-fd_spot3-0192.jpk-force", td2)
     shutil.copy2(
-        datadir / "calibration_force-save-2015.02.04-11.25.21.294.jpk-force",
+        data_path /
+        "fmt-jpk-cl_calibration_force-save-2015.02.04-11.25.21.294.jpk-force",
         td3)
     file_list = afmformats.find_data(td)
     assert len(file_list) == 1
-    assert file_list[0].samefile(td2 / "spot3-0192.jpk-force")
+    assert file_list[0].samefile(td2 / "fmt-jpk-fd_spot3-0192.jpk-force")
 
 
 def test_find_data_invalid_missing():
     td = pathlib.Path(tempfile.mkdtemp(prefix="find_data_invalid_"))
-    shutil.copy2(datadir / "spot3-0192.jpk-force", td / "spot.unknown")
+    shutil.copy2(data_path / "fmt-jpk-fd_spot3-0192.jpk-force",
+                 td / "spot.unknown")
     file_list = afmformats.find_data(td)
     assert not file_list
